=======
History
=======

0.1.0 (2020-11-08)
------------------

* New API to get the output
* Fixed test cases
* Extended documentation on the README file


0.1.0 (2020-11-05)
------------------

* First release on PyPI.
